==> nextcloud-25.0.8.tgz: nextcloud/apps/updatenotification/l10n/gl.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} está dispoñíbel. Obteña máis información sobre como actualizar.",
    "Channel updated" : "Canle actualizada",
    "Web updater is disabled" : "O actualizador web está desactivado",
    "Update notifications" : "Actualizar as notificacións",
    "The update server could not be reached since %d days to check for new updates." : "Non foi posíbel acadar o servidor de actualizacións dende hai %d días para comprobar se hai novas actualizacións.",
    "Please check the Nextcloud and server log files for errors." : "Revise os ficheiros de rexistro de Nextcloud e do servidor na busca de erros.",
    "Update to %1$s is available." : "Está dispoñíbel  unha actualización para %1$s.",
    "Update to {serverAndVersion} is available." : "Está dispoñíbel a actualización para {serverAndVersion}.",
    "Update for {app} to version %s is available." : "Está dispoñíbel unha actualización para {app} á versión %s.",
    "Update notification" : "Notificación de actualización",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Amosa as notificacións de actualizacións para o Nexcloud e fornece o SSO para o actualizador.",
    "Update" : "Actualizar",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "A versión que ten en execución xa non dispón de mantemento. Asegúrese de actualizar a unha versión asistida tecnicamente tan cedo como lle sexa posíbel.",
    "Apps missing compatible version" : "Aplicacións que carecen de versión compatíbel",
    "View in store" : "Ver na tenda",
    "Apps with compatible version" : "Aplicacións con versión compatíbel",
    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "Teña en conta que o actualizador web non está recomendado con máis de 100 usuarios! Empregue o actualizador da liña de ordes.",
    "Open updater" : "Abrir o actualizador",
    "Download now" : "Descargar agora",
    "Please use the command line updater to update." : "Utilice o actualizador de liña de ordes para actualizar.",
    "What's new?" : "Que hai de novo?",
    "The update check is not yet finished. Please refresh the page." : "A comprobación de actualización aínda non rematou. Recargue a páxina.",
    "Your version is up to date." : "A súa versión está actualizada.",
    "A non-default update server is in use to be checked for updates:" : "Está en uso un servidor de actualizacións que non é o predeterminado para comprobar as actualizacións:",
    "You can change the update channel below which also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Pode cambiar a canle de actualización a seguir, o que tamén afecta á páxina de xestión de aplicacións. p.ex. após cambiar á canle beta, ofreceranse actualizacións da aplicación beta na páxina de xestión de aplicacións.",
    "Update channel:" : "Canle de actualización:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Sempre poderá actualizar á versión más recente, mais nunca poderá volver a unha canle máis estábel.",
    "Notify members of the following groups about available updates:" : "Notificar aos membros dos seguintes grupos sobre actualizacións dispoñíbeis:",
    "No groups" : "Non hai grupos",
    "Only notifications for app updates are available." : "Só están dispoñíbeis as notificacións para actualizacións de aplicación.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "A canle de actualización seleccionada fai obsoletas as notificacións dedicadas para o servidor.",
    "The selected update channel does not support updates of the server." : "A canle de actualización seleccionada non admite actualizacións do servidor.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Hai dispoñíbel unha versión nova:<strong>{newVersionString}</strong>",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Ten en conta que após unha nova versión, a actualización só aparece após a primeira versión menor ou posterior.publicamos novas versións repartidas ao longo do tempo para os nosos usuarios e ás veces omitimos unha versión cando se atopan problemas. Máis información sobre actualizacións e canles de publicación en {link}",
    "Checked on {lastCheckedDate}" : "Comprobado o {lastCheckedDate}",
    "Checking apps for compatible versions" : "Comprobando as versións compatíbeis das aplicacións",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Asegúrese de que o seu config.php non ten configurado <samp>appstoreenabled</samp> como «false».",
    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "Non foi posíbel conectar á Tenda de aplicacións ou non se devolveu ningunha actualización. Busque actualizacións manualmente ou asegúrese de que o seu servidor ten acceso a Internet e pode conectarse á Tenda de aplicacións.",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "<strong>Todas</strong> as aplicacións teñen dispoñíbel unha versión compatíbel para esta versión de Nextcloud.",
    "View changelog" : "Ver o rexistro de cambios",
    "Enterprise" : "Empresarial",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Para uso empresarial. Ofrece sempre o último nivel de parches, pero non se actualizará inmediatamente á seguinte versión principal. Esta actualización prodúcese unha vez que Nextcloud GmbH teña feitas as probas e reforzos para implementacións a gran escala e de obxectivos críticos. Esta canle só está dispoñíbel para os clientes e fornece o paquete Nextcloud empresarial.",
    "Stable" : "Estábel",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "A versión estábel máis recente. É axeitada para uso en produción e actualizarase sempre á última versión maior.",
    "Beta" : "Beta",
    "A pre-release version only for testing new features, not for production environments." : "Unha versión preliminar só para probar funcionalidades novas, non para contornos de produción",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["<strong>%n</strong> aplicación non ten dispoñíbel unha versión compatíbel para esta versión de Nextcloud.","<strong>%n</strong> aplicacións non teñen dispoñíbel unha versión compatíbel para esta versión de Nextcloud."],
    "Update for %1$s to version %2$s is available." : "Está dispoñíbel unha actualización para %1$s á versión %2$s."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-26.0.11p1.tgz: nextcloud/apps/updatenotification/l10n/gl.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} está dispoñíbel. Obteña máis información sobre como actualizar.",
    "Channel updated" : "Canle actualizada",
    "Web updater is disabled" : "O actualizador web está desactivado",
    "Update notifications" : "Actualizar as notificacións",
    "The update server could not be reached since %d days to check for new updates." : "Non foi posíbel acadar o servidor de actualizacións dende hai %d días para comprobar se hai novas actualizacións.",
    "Please check the Nextcloud and server log files for errors." : "Revise os ficheiros de rexistro de Nextcloud e do servidor na busca de erros.",
    "Update to %1$s is available." : "Está dispoñíbel  unha actualización para %1$s.",
    "Update to {serverAndVersion} is available." : "Está dispoñíbel a actualización para {serverAndVersion}.",
    "Update for {app} to version %s is available." : "Está dispoñíbel unha actualización para {app} á versión %s.",
    "Update notification" : "Notificación de actualización",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Amosa as notificacións de actualizacións para o Nexcloud e fornece o SSO para o actualizador.",
    "Update" : "Actualizar",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "A versión que ten en execución xa non dispón de mantemento. Asegúrese de actualizar a unha versión asistida tecnicamente tan cedo como lle sexa posíbel.",
    "Apps missing compatible version" : "Aplicacións que carecen de versión compatíbel",
    "View in store" : "Ver na tenda",
    "Apps with compatible version" : "Aplicacións con versión compatíbel",
    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "Teña en conta que o actualizador web non está recomendado con máis de 100 usuarios! Empregue o actualizador da liña de ordes.",
    "Open updater" : "Abrir o actualizador",
    "Download now" : "Descargar agora",
    "Web updater is disabled. Please use the command line updater or the appropriate update mechanism for your installation method (e.g. Docker pull) to update." : "O actualizador web está desactivado. Use o actualizador de liña de ordes ou o mecanismo de actualización axeitado para o seu método de instalación (por exemplo, Docker pull) para actualizar.",
    "What's new?" : "Que hai de novo?",
    "View changelog" : "Ver o rexistro de cambios",
    "The update check is not yet finished. Please refresh the page." : "A comprobación de actualización aínda non rematou. Recargue a páxina.",
    "Your version is up to date." : "A súa versión está actualizada.",
    "A non-default update server is in use to be checked for updates:" : "Está en uso un servidor de actualizacións que non é o predeterminado para comprobar as actualizacións:",
    "Update channel" : "Canle de actualización:",
    "Changing the update channel also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Cambiar a canle de actualización tamén afecta á páxina de xestión de aplicacións. p.ex. após cambiar á canle beta, ofreceranse actualizacións da aplicación beta na páxina de xestión de aplicacións.",
    "Current update channel:" : "Canle de actualización actual:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Sempre poderá actualizar á versión más recente, mais nunca poderá volver a unha canle máis estábel.",
    "Notify members of the following groups about available updates:" : "Notificar aos membros dos seguintes grupos sobre actualizacións dispoñíbeis:",
    "No groups" : "Non hai grupos",
    "Only notifications for app updates are available." : "Só están dispoñíbeis as notificacións para actualizacións de aplicación.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "A canle de actualización seleccionada fai obsoletas as notificacións dedicadas para o servidor.",
    "The selected update channel does not support updates of the server." : "A canle de actualización seleccionada non admite actualizacións do servidor.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Hai dispoñíbel unha versión nova:<strong>{newVersionString}</strong>",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Ten en conta que após unha nova versión, a actualización só aparece após a primeira versión menor ou posterior.publicamos novas versións repartidas ao longo do tempo para os nosos usuarios e ás veces omitimos unha versión cando se atopan problemas. Máis información sobre actualizacións e canles de publicación en {link}",
    "Checking apps for compatible versions" : "Comprobando as versións compatíbeis das aplicacións",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Asegúrese de que o seu config.php non ten estabelecido <samp>appstoreenabled</samp> como «false».",
    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "Non foi posíbel conectar á Tenda de aplicacións ou non se devolveu ningunha actualización. Busque actualizacións manualmente ou asegúrese de que o seu servidor ten acceso a Internet e pode conectarse á Tenda de aplicacións.",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "<strong>Todas</strong> as aplicacións teñen dispoñíbel unha versión compatíbel para esta versión de Nextcloud.",
    "Enterprise" : "Empresarial",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Para uso empresarial. Ofrece sempre o último nivel de parches, pero non se actualizará inmediatamente á seguinte versión principal. Esta actualización prodúcese unha vez que Nextcloud GmbH teña feitas as probas e reforzos para implementacións a gran escala e de obxectivos críticos. Esta canle só está dispoñíbel para os clientes e fornece o paquete Nextcloud empresarial.",
    "Stable" : "Estábel",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "A versión estábel máis recente. É axeitada para uso en produción e actualizarase sempre á última versión maior.",
    "Beta" : "Beta",
    "A pre-release version only for testing new features, not for production environments." : "Unha versión preliminar só para probar funcionalidades novas, non para contornos de produción",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["<strong>%n</strong> aplicación non ten dispoñíbel unha versión compatíbel para esta versión de Nextcloud.","<strong>%n</strong> aplicacións non teñen dispoñíbel unha versión compatíbel para esta versión de Nextcloud."],
    "Please use the command line updater to update." : "Utilice o actualizador de liña de ordes para actualizar.",
    "You can change the update channel below which also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Pode cambiar a canle de actualización a seguir, o que tamén afecta á páxina de xestión de aplicacións. p.ex. após cambiar á canle beta, ofreceranse actualizacións da aplicación beta na páxina de xestión de aplicacións.",
    "Update channel:" : "Canle de actualización:",
    "Checked on {lastCheckedDate}" : "Comprobado o {lastCheckedDate}"
},
"nplurals=2; plural=(n != 1);");
